@@ -4,4 +4,4 @@ python setup.py bdist_wheel
 python setup.py bdist_egg
 twine check dist/*
 #python setup.py sdist upload
-twine upload dist/*whl dist/*gz dist/*egg
+twine upload --skip-existing dist/*whl dist/*gz dist/*egg
